import ExtensionClass
from Globals import DTMLFile

class HtmlAreaMixin(ExtensionClass.Base):
    """
    A mixin class just to provide the DTML method HtmlArea_script.
    It doesn't define an own object type you could create objects of.

    You don't need to use the mixin class; you may as well
    simply insert the contents of the method into the method[s] you intend
    to use.
    
    Methods:

    **htmlArea_prefix** -- includes the editor.js if the browser
                           is recognised as a supported one
                           (MSIE/Win >= 5.5)

    **htmlArea_editor** -- creates an editor for the specified textarea,
                           several options

    **htmlArea_style** -- creates a html link to include the standard
                          stylesheet
    """
    htmlArea_prefix = DTMLFile('dtml/HtmlArea_prefix', globals())
    # name deprecated:
    HtmlArea_prefix = DTMLFile('dtml/HtmlArea_prefix', globals())

    def htmlArea_editor(self, 
                        name, # name of the textarea
                        toolbar='standard',
                        width=None,
                        height=None,
                        **buttons):
        """
        Inserts the code to turn the textarea with the given *name*
        into a WYSIWYG editor. Must be called in the html body;
        requires the use of --> htmlArea_prefix in the html head.

        Arguments:

        **name** -- the name of the textarea

        **height** -- a height specification for the editor (px or percentage);
                      default: '200px' (may change)

        **width** -- a width specification for the editor (px or percentage)
                      default: '100%' (may change)

        **toolbar** -- allows the preselection of a set of available buttons.
                     Currently supported (string values):

                     *simple* -- bold, italic, underline, about only

                     *restricted* -- adds justify buttons and links

                     *normal* -- adds lists and indentations (includes *restricted*)

                     *standard* -- what htmlArea 2.03 considers standard
                       (doesn't explicitely define the toolbar unless 
                       specific buttons requested, see below)

                     *all* -- all standard buttons (of htmlarea 2.03) known to
                              this Zope product
                     
        **\*\*buttons** -- allows to switch on or off single buttons
                     by specifying named arguments
        """
        if not (height or width or (toolbar != 'standard') or buttons):
            return """\n<script language="javascript1.2"><!--
editor_generate('%s');
//--></script>""" % name

        res = """\n<script language="javascript1.2" defer><!--\n"""
        
        tint = type(0)
        if height is None:
            height = '200px'
        elif type(height) == tint:
            height = '%dpx' % height
        
        if width  is None:
            width  = '100%'
        elif type(width) == tint:
            if width > 100:
                width = '%dpx' % width
            else:
                width = '%d%%' % width

        if toolbar == 'standard' and buttons:
            toolbar = 'normal'

        if toolbar == 'all':
            _toolbar = { 'help': 0, # not yet filled with useful content in htmlArea 2.03
                         'fontstyle': 0, # does't seem to work yet
                        }
            default = 1
        else:
            if not (toolbar in ('simple', 'restricted', 'normal', 'standard')):
                res += '// unknown toolbar set: "%s"\n' % toolbar
                toolbar = 'standard'
                res += '// changed to: "%s"\n' % toolbar
            default = 0
            _toolbar = { 'bold': 1,
                         'italic': 1,
                         'underline': 1,
                         'about': 1,
                        }
            if toolbar in ('restricted', 'normal'):
                _toolbar.update({'justifyleft': 1,
                                 'justifyright': 1,
                                 'justifycenter': 1,
                                })
                if toolbar in ('normal',):
                    for k in ['fontname', 'fontsize',
                            'OrderedList','UnOrderedList','Outdent','Indent',
                            'forecolor','backcolor',
                            'HorizontalRule','Createlink','InsertImage','InsertTable','htmlmode',
                            'popupeditor','about']:
                        _toolbar[k] = 1
        if buttons:
            _toolbar.update(buttons)

        # defer: empty attribute, prevents the script from generating code; newer MSIEs only
        res += 'var custom = new Object();\n'
        if width:
            res += "custom.width = '%s';\n" % width
        if height:
            res += "custom.height = '%s';\n" % height
        lines = []

        if buttons or (toolbar != 'standard'):
            tmpline = []
            for keyset in ( ('fontname', 'fontsize', 'fontstyle',
                             'bold', 'italic', 'underline',
                             'strikethrough','subscript','superscript',),
                            ('justifyleft','justifycenter','justifyright',),
                            ('OrderedList','UnOrderedList','Outdent','Indent',),
                            ('forecolor','backcolor',),
                            ('HorizontalRule','Createlink','InsertImage',),
                            ('htmlmode', 'about','help'),
                           ):
                for key in keyset:
                    if _toolbar.get(key, default):
                        tmpline.append(key)
                if tmpline:
                    lines.append("'%s'" % "', '".join(tmpline))
                    tmpline = []
            
        if lines:
            res += 'custom.toolbar = [[%s]];\n' % \
                   ", 'separator'],\n                  [".join(lines)
                         
        res += "editor_generate('%s', custom);\n" % name
        res += '//--></script>'
        return res

    def htmlArea_style(self):
        "simply includes the standard styles"
        return '<link rel="stylesheet" type="text/css" src="/misc_/htmlarea/standard.css">'
    
